==> openflowplugin-extension-nicira-0.8.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/copy/value/into/field/_case/FlowModCopyValueIntoField.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.value.into.field._case;
import java.lang.Integer;
import java.lang.Long;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-copy-value-into-field {
 *   leaf flow-mod-num-bits {
 *     type uint16;
 *   }
 *   leaf value {
 *     type uint16;
 *   }
 *   leaf dst-field {
 *     type uint32;
 *   }
 *   leaf dst-ofs {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-copy-value-into-field-case/flow-mod-copy-value-into-field</i>
 *
 * <p>To create instances of this class use {@link FlowModCopyValueIntoFieldBuilder}.
 * @see FlowModCopyValueIntoFieldBuilder
 *
 */
public interface FlowModCopyValueIntoField
    extends
    ChildOf<FlowModSpec>,
    Augmentable<FlowModCopyValueIntoField>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-copy-value-into-field");

    /**
     * @return <code>java.lang.Integer</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    @Nullable Integer getFlowModNumBits();
    
    /**
     * @return <code>java.lang.Integer</code> <code>value</code>, or <code>null</code> if not present
     */
    @Nullable Integer getValue();
    
    /**
     * @return <code>java.lang.Long</code> <code>dstField</code>, or <code>null</code> if not present
     */
    @Nullable Long getDstField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>dstOfs</code>, or <code>null</code> if not present
     */
    @Nullable Integer getDstOfs();

}

==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/copy/value/into/field/_case/FlowModCopyValueIntoField.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.value.into.field._case;
import java.lang.Integer;
import java.lang.Long;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-copy-value-into-field {
 *   leaf flow-mod-num-bits {
 *     type uint16;
 *   }
 *   leaf value {
 *     type uint16;
 *   }
 *   leaf dst-field {
 *     type uint32;
 *   }
 *   leaf dst-ofs {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-copy-value-into-field-case/flow-mod-copy-value-into-field</i>
 *
 * <p>To create instances of this class use {@link FlowModCopyValueIntoFieldBuilder}.
 * @see FlowModCopyValueIntoFieldBuilder
 *
 */
public interface FlowModCopyValueIntoField
    extends
    ChildOf<FlowModSpec>,
    Augmentable<FlowModCopyValueIntoField>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-copy-value-into-field");

    /**
     * @return <code>java.lang.Integer</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    @Nullable Integer getFlowModNumBits();
    
    /**
     * @return <code>java.lang.Integer</code> <code>value</code>, or <code>null</code> if not present
     */
    @Nullable Integer getValue();
    
    /**
     * @return <code>java.lang.Long</code> <code>dstField</code>, or <code>null</code> if not present
     */
    @Nullable Long getDstField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>dstOfs</code>, or <code>null</code> if not present
     */
    @Nullable Integer getDstOfs();

}
